/************************************************************************/
/*  Routines to get block information from active file.			*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: get_block_info.c,v 1.3 2009/05/14 23:33:54 doug Exp $ ";
#endif

#include <stdio.h>

#include "qlib2.h"

#include "params.h"
#include "st_info.h"
#include "externals.h"
#include "procs.h"

/************************************************************************/
/*  get_block_info:							*/
/*	Get information about the next block in stream.			*/
/************************************************************************/
void get_block_info
   (ST_INFO	*st_p)		/* ptr to current stream header.	*/
{
    int	    *p;
    int	    steim_comp;
    BS		    *bs;	/* ptr to blockette structure.		*/
    BS		    *ibs;	/* ptr to blockette structure.		*/
    BLOCKETTE_HDR   *bh;	/* ptr to blockette hdr.		*/
    double   sps;

    if (my_wordorder < 0)
	get_my_wordorder();
    switch (st_p->hdr_type) {
    case SDR_HDR_TYPE:
	st_p->cur_hdr = decode_hdr_sdr ((SDR_HDR *)st_p->iob->buf,
					st_p->iob->free);
	break;
    default:
	fprintf (stderr, "Error: unknown header type for block %d from stream %s\n", 
		 st_p->num_blocks+1, st_p->filename);
	exit(1);
	break;
    }
    if (st_p->cur_hdr == NULL) {
	fprintf (stderr, "Error: unable to get header from block %d from stream %s\n", 
		 st_p->num_blocks+1, st_p->filename);
	exit(1);
    }
    st_p->blksize = st_p->cur_hdr->blksize;
    /* Handle qlib2 oddity for "empty" blocks (block with no data samples). */
    if (tdiff(st_p->cur_hdr->endtime, st_p->cur_hdr->begtime) < 0) 
	st_p->cur_hdr->endtime = st_p->cur_hdr->begtime;

    /* Get the recno from the first and last opaque blockette in the record. */
    st_p->cur_hdr->xm1 = IGNORE2000;
    st_p->cur_hdr->xm2 = IGNORE2000;
    ibs = st_p->cur_hdr->pblockettes;
    while ((ibs = find_pblockette(st_p->cur_hdr,ibs,2000)) != NULL) {
	bs = ibs;
	ibs = ibs->next;
	/* Save last blockette 2000 record_num.	*/
	st_p->cur_hdr->xm2 = ((BLOCKETTE_2000 *)(bs->pb))->record_num;
	if (my_wordorder != st_p->cur_hdr->hdr_wordorder) {
	    swab4 (&(st_p->cur_hdr->xm2));
	}
	if (st_p->cur_hdr->xm1 != IGNORE2000) continue;
	/* Save first blockette 2000 record_num.	*/
	st_p->cur_hdr->xm1 = ((BLOCKETTE_2000 *)(bs->pb))->record_num;
	if (my_wordorder != st_p->cur_hdr->hdr_wordorder) {
	    swab4 (&(st_p->cur_hdr->xm1));
	}
    }
    ++(st_p->num_blocks);
}
