/************************************************************************/
/*  Parameters for qmerge:						*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

/*	$Id: params.h,v 1.2 2000/10/26 13:39:25 doug Exp $ 	*/

#ifndef	DEFAULT_NETWORK
#define	DEFAULT_NETWORK	"BK"
#endif

/* NOTE:  Specify pattern with double percents so that it can be    */
/* used in printf string.  The code that used the string will	    */
/* treat a %% as a single % for the purposes of pattern matching.   */
#ifndef	DEFAULT_VERIFY_PATTERN
#define	DEFAULT_VERIFY_PATTERN	"%%S.%%N.%%C.D.%%Y.%%j"
#endif

#define NULLDEV		"/dev/null"

#define	DEBUG
#define	DEBUG_SLEW	1
#define	DEBUG_TIME	2
#define	DEBUG_BLOCK	4
#define	DEBUG_HDRS	8
#define	DEBUG_FLAG	16
#define	DEBUG_STREAM	32
#define	DEBUG_OUT	64
#define	DEBUG_RAW	128
#define	DEBUG_ASCII	1024
#define	DEBUG_ANY	\
    (DEBUG_BLOCK | DEBUG_HDRS | DEBUG_SLEW | DEBUG_TIME | DEBUG_FLAG | \
     DEBUG_STREAM | DEBUG_OUT | DEBUG_RAW | DEBUG_ASCII)
#define	    debug(val)  (debug_option & (val))

/*  Global parameters used throughout the program.			*/
/*  MAX_BLKSIZE:    maximum blocksize for input data.			*/
/*  BUFSIZE:	    size of input and output file buffers.		*/
/*  NOTE:   BUFSIZE must be large enough enought to hold any type of 	*/
/*	    file header, AND large enough to hold a block of data as	*/
/*	    well as additional STEIM blocks caused by reblocking.	*/

#define	MAX_BLKSIZE	8192
#define	BUFSIZE		(MAX_BLKSIZE * 2 )

#define	QDA_HDR_SIZE	64
#define	SDR_HDR_SIZE	64
#define	DRM_HDR_SIZE	64	/* This is WRONG -- look it up! */
#define	DRM_FILE_HDR_SIZE	sizeof(STORE_FILE_HEAD)
#define	MAX_HDR_SIZE		sizeof(STORE_FILE_HEAD)

/*  RATE(rate) is in samples/second.					*/
/*  TOL(rate) = max size of gap in ticks that can be tolerated between	*/
/*  adjacent blocks of data at specified sample rate without causing a	*/
/*  hard time tear.							*/
/*  MERGE_TOL(rate) = max size of gap in ticks that can be tolerated	*/
/*  when merging adjacent blocks of data at specified sample rate 	*/
/*  without causing the start of a new block.				*/
/*  NOTE:  values are still defined in terms of TICKS.			*/

#define	TTOL_MULT		.4
#define	TOL(rate,mult)		((TTOL_MULT*USECS_PER_SEC)/(sps_rate(rate,mult)))
#define	MTOL_MULT		.1
#define	MERGE_TOL(rate,mult)	((MTOL_MULT*USECS_PER_SEC)/(sps_rate(rate,mult)))
#define	SPS_80_THRESHOLD	(1*TICKS_PER_MSEC*USECS_PER_TICK)

#define	SMALL_BLOCK_BIAS	1
#define	LARGE_BLOCK_BIAS	2
#define	NO_BIAS			0
#define	START_BIAS		SMALL_BLOCK_BIAS
#define	RUN_BIAS		NO_BIAS

#ifndef	DEFAULT_OUTPUT_BLKSIZE
#define	DEFAULT_OUTPUT_BLKSIZE	4096
#endif
#define	out_frames_per_block(blksize,hdrsize)	((int)((blksize-(hdrsize))/FRAMESIZE))

typedef struct _range {
    int	first;			/* first value in range.		*/
    int	last;			/* last value in range.			*/
} RANGE;

typedef struct _blockette_info {
    int blockette;		/* blockette number.			*/
    double seed_version;	/* earliest seed version containing it	*/
} BLOCKETTE_INFO;

/* Define relation operators for blockette 200 record numbers.		*/
/* HR2000 is half of the range for blockette 2000 record numbers.	*/
#define	MAX2000	0x7FFFFFFF
#define HR2000	0x40000000 
#define	EQ2000(a,b) ( a==b )
#define	GT2000(a,b) ( ((a>b) && (a-b)<=HR2000) || ((a<b) && (b-a) > HR2000) )
#define	GE2000(a,b) ( EQ2000(a,b) || GT2000(a,b) )
#define	NE2000(a,b) ( ! EQ2000(a,b) )
#define	LT2000(a,b) ( GT2000(b,a) )
#define	LE2000(a,b) ( GE2000(b,a) )
#define	NEXT2000(a) ( (a<0) ? a : (a>=MAX2000) ? 0 : a+1 )
#define	PREV2000(a) ( (a<0) ? a : (a==0) ? MAX2000 : a-1 )
#define	DIFF2000(a,b) (EQ2000(a,b) ? 0 : \
		       GT2000(a,b) ? (((a-b)+HR2000)%HR2000) : \
		       (-1*(((b-a)+HR2000)%HR2000)))
#define IGNORE2000  -1
#define	DEFAULT_BLOCK_TOL   100
